@@ -5,7 +5,7 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use strict;
 
@@ -85,6 +85,7 @@ sub set {
     
     $self->[-1]->{$key} = $value;
 }
+*put = \&set;
 
 sub size {
     my $self = shift;
@@ -156,6 +157,8 @@ to find the value.
 
 =item set ( $key => $value )
 
+=item put ( $key => $value ) 
+
 Sets the value of I<$key> to I<$value>.
 
 =item keys ()
